@@ -40,6 +40,7 @@ class SLSLogHook(Hook):
     def on_exit(self, res: TestResult):
         self.log(res.name, "test", res.status, res.elapse, {
             "testID": self.test_id,
+            "name": res.name,
             "casePass": res.case_pass,
             "caseFail": res.case_fail,
             "caseSkip": res.case_skip,
@@ -53,6 +54,7 @@ class SLSLogHook(Hook):
     def on_test_end(self, res: TestResult):
         self.log(res.name, "subTest", res.status, res.elapse, {
             "testID": self.test_id,
+            "name": res.name,
             "casePass": res.case_pass,
             "caseFail": res.case_fail,
             "caseSkip": res.case_skip,
@@ -66,6 +68,7 @@ class SLSLogHook(Hook):
     def on_set_up_end(self, res: CaseResult):
         self.log(res.name, "setUp", res.status, res.elapse, {
             "testID": self.test_id,
+            "name": res.name,
             "stepPass": res.step_pass,
             "stepFail": res.step_fail,
             "stepSkip": res.step_skip,
@@ -76,6 +79,7 @@ class SLSLogHook(Hook):
     def on_case_end(self, res: CaseResult):
         self.log(res.name, "case", res.status, res.elapse, {
             "testID": self.test_id,
+            "name": res.name,
             "stepPass": res.step_pass,
             "stepFail": res.step_fail,
             "stepSkip": res.step_skip,
@@ -86,6 +90,7 @@ class SLSLogHook(Hook):
     def on_tear_down_end(self, res: CaseResult):
         self.log(res.name, "tearDown", res.status, res.elapse, {
             "testID": self.test_id,
+            "name": res.name,
             "stepPass": res.step_pass,
             "stepFail": res.step_fail,
             "stepSkip": res.step_skip,
@@ -101,6 +106,8 @@ class SLSLogHook(Hook):
         else:
             status = "fail"
         self.log(res.name, "step", status, res.elapse, {
+            "ctx": res.ctx,
+            "name": res.name,
             "assertionPass": res.assertion_pass,
             "assertionFail": res.assertion_fail,
         })
